@@ -44,6 +44,34 @@ class PopcornTime:
 
         return urljoin(self._BASE_URL, path)
 
+    @staticmethod
+    def _get_torrent_seeds(torrent):
+        """
+            Movie have different seed name for the same thing so
+            this function will handle that difference
+
+            :param torrent:
+            :return:
+        """
+        try:
+            return torrent['seeds']
+        except KeyError:
+            return torrent['seed']
+
+    @staticmethod
+    def _get_torrent_peers(torrent):
+        """
+            Movie have different seed name for the same thing so
+            this function will handle that difference
+
+            :param torrent:
+            :return:
+        """
+        try:
+            return torrent['peers']
+        except KeyError:
+            return torrent['peer']
+
     def set_logging_level(self, level: int) -> int:
         """
             Sets the logging level
@@ -92,6 +120,34 @@ class PopcornTime:
 
         return self._MIN_PEERS
 
+    def get_server_status(self) -> (requests.Response.json, None):
+        """
+            Get the server status
+
+            :return: dict (Example: {"repo": ..., "version": ..., "uptime": ...})
+        """
+
+        status = self._get(self._build_url('/status'))
+
+        if status:
+            self.log.info('Got status')
+            return status
+        return None
+
+    def get_shows_stats(self) -> (requests.Response.json, None):
+        """
+            Get the shows stats
+
+            :return: dict (Example: {"action & adventure": {"count": 600, "title": "Action & Adventure"}})
+        """
+
+        stats = self._get(self._build_url('/shows/stat'))
+
+        if stats:
+            self.log.info('Got shows stats')
+            return stats
+        return None
+
     def get_shows_page(self, page: (int, str)) -> (requests.Response.json, None):
         """
             Gets the shows page
@@ -109,9 +165,9 @@ class PopcornTime:
 
     def get_show(self, show_id: (int, str)) -> (requests.Response.json, None):
         """
-            Gets the show page
+            Get the show
 
-            :param show_id: int (Example: 1)
+            :param show_id: int (Example: tt1285016)
             :return: dict (Example: {"status": "success", "data": {"show": {"...show data..."}}}
         """
 
@@ -122,6 +178,20 @@ class PopcornTime:
             return show
         return None
 
+    def get_random_show(self) -> (requests.Response.json, None):
+        """
+            Get a random show
+
+            :return: dict (Example: {"_id": "...", ...})
+        """
+
+        show = self._get(self._build_url(f'/random/show'))
+
+        if show:
+            self.log.info(f'Got random show {show["_id"]}')
+            return show
+        return None
+
     def get_best_quality_torrent(self, torrents: dict) -> (tuple, None):
         """
             Gets the show torrent with the best quality
@@ -130,6 +200,14 @@ class PopcornTime:
             :return: tuple<dict, int> (Example: ({"url": "magnet:?xt=urn:btih:..."}, 1080))
         """
 
+        # Some torrents have different "sections" for each language so we will try
+        # to get the en language all the time
+
+        try:
+            torrents = torrents['en']
+        except KeyError:
+            pass
+
         best_quality = -1
         best_quality_torrent = None
         for torrent_quality, torrent_data in torrents.items():
@@ -137,7 +215,8 @@ class PopcornTime:
             quality = int(torrent_quality.replace('p', ''))
             if quality > best_quality:
                 # Check if torrent quality has minimum seeds/peers
-                if torrent_data['seeds'] >= self._MIN_SEEDS and torrent_data['peers'] >= self._MIN_PEERS:
+                if self._get_torrent_seeds(torrent_data) >= self._MIN_SEEDS and \
+                        self._get_torrent_peers(torrent_data) >= self._MIN_PEERS:
                     best_quality = quality
                     best_quality_torrent = torrent_data
 
@@ -153,34 +232,61 @@ class PopcornTime:
         logging.info('No torrents meet the minimum requirements and no torrent to revert to')
         return None
 
+    def get_movies_stats(self) -> (requests.Response.json, None):
+        """
+            Get the movies stats
+
+            :return: dict (Example: {"action & adventure": {"count": 600, "title": "Action & Adventure"}})
+        """
+
+        stats = self._get(self._build_url('/movies/stat'))
+
+        if stats:
+            self.log.info('Got movies stats')
+            return stats
+        return None
+
     def get_movies_page(self, page: (int, str)) -> (requests.Response.json, None):
         """
-            Gets the shows page
+            Gets the movies page
 
             :param page: int (Example: 1)
             :return: dict (Example: {_id: "...", ...})
         """
 
-        shows = self._get(self._build_url(f'/movies/{page}'))
+        movies = self._get(self._build_url(f'/movies/{page}'))
 
-        if shows:
+        if movies:
             self.log.info(f'Got movies page {page}')
-            return shows
+            return movies
         return None
 
     def get_movie(self, movie_id: (int, str)) -> (requests.Response.json, None):
         """
-            Gets the show page
+            Get the movie
 
-            :param movie_id: int (Example: 1)
+            :param movie_id: int (Example: tt1234567)
             :return: dict (Example: {_id: "...", ...})
         """
 
-        show = self._get(self._build_url(f'/movie/{movie_id}'))
+        movie = self._get(self._build_url(f'/movie/{movie_id}'))
 
-        if show:
+        if movie:
             self.log.info(f'Got movie {movie_id}')
-            return show
+            return movie
+        return None
+
+    def get_random_movie(self) -> (requests.Response.json, None):
+        """
+            Gets a random movie from the api
+
+            :return: dict (Example: {_id: "...", ...})
+        """
+        movie = self._get(self._build_url(f'/random/movie'))
+
+        if movie:
+            self.log.info(f'Got random movie {movie["_id"]}')
+            return movie
         return None
 
 
@@ -194,7 +300,8 @@ class TestPopcorn(unittest.TestCase):
         req = False
         try:
             req = requests.get("https://google.com", timeout=10)
-        except Exception: pass
+        except Exception:
+            pass
 
         if not req:
             logging.error('Testing internet connection failed, please check your connection and try again!')
@@ -202,26 +309,35 @@ class TestPopcorn(unittest.TestCase):
 
         logging.info("Internet connection test was successful")
 
+    def test_get_show_stats(self):
+        self.assertIsNotNone(self.popAPI.get_shows_stats)
+
     def test_get_shows_page(self):
         self.assertIsNotNone(self.popAPI.get_shows_page, 1)
 
     def test_get_show(self):
-        #TODO Add show id from IMDB
-        self.assertIsNotNone(self.popAPI.get_show, "tt")
+        self.assertIsNotNone(self.popAPI.get_show, "tt10160804")
+
+    def test_get_random_show(self):
+        self.assertIsNotNone(self.popAPI.get_random_show)
 
     def test_get_best_quality_torrent(self):
-        # TODO Add show id from IMDB
-        show = self.popAPI.get_show("tt")
+        show = self.popAPI.get_movie("tt0111161")
         torrents = show["torrents"]
         self.assertIsNotNone(self.popAPI.get_best_quality_torrent(torrents))
 
+    def test_get_movies_stats(self):
+        self.assertIsNotNone(self.popAPI.get_movies_stats)
+
     def test_get_movie_page(self):
         self.assertIsNotNone(self.popAPI.get_movies_page, 1)
 
     def test_get_movie(self):
-        # TODO Add movie id from IMDB
-        self.assertIsNotNone(self.popAPI.get_movie, "tt")
+        self.assertIsNotNone(self.popAPI.get_movie, "tt0111161")
+
+    def test_get_random_movie(self):
+        self.assertIsNotNone(self.popAPI.get_random_movie)
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
